# emojiscan
A Python package to extract and filter unique emojis from files, allowing users to see which emojis are compatible with a platform. The project supports files in HTML and TXT. Ideal for testing on different platforms like listing sites (e.g., Sahibinden), where emojis may not display properly.
